
**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Run this code '...'
2. Use this argument on function '....'

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Your computer (please complete the following information):**
 - OS: [e.g. Linux]
 - Python version [e.g. 3.6.5]
 - isbnlib version [e.g. 3.8.5]

**How did you install isbnlib?**
[e.g. `pip install isbnlib`]

**Additional context**
Add any other context about the problem here.
